@@ -21,7 +21,7 @@ except ImportError:
 
 from flask_discord_interactions.command import Command, SlashCommandGroup
 from flask_discord_interactions.context import Context, ApplicationCommandType
-from flask_discord_interactions.models import Message, ResponseType
+from flask_discord_interactions.models import Message, Modal, ResponseType
 
 
 class InteractionType:
@@ -495,7 +495,7 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
 
         return command.make_context_and_run(self, current_app, data)
 
-    def run_handler(self, data):
+    def run_handler(self, data, *, allow_modal=True):
         """
         Run the corresponding custom ID handler given incoming interaction
         data.
@@ -511,6 +511,12 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
         args = context.create_handler_args(handler)
         result = handler(context, *args)
 
+        if isinstance(result, Modal):
+            if allow_modal:
+                return result
+            else:
+                raise ValueError("Cannot return a Modal to that interaction type.")
+
         return Message.from_return_value(result)
 
     def run_autocomplete(self, data):
@@ -596,6 +602,14 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
             elif interaction_type == InteractionType.APPLICATION_COMMAND_AUTOCOMPLETE:
                 return jsonify(self.run_autocomplete(request.json).dump())
 
+            elif interaction_type == InteractionType.MODAL_SUBMIT:
+                return jsonify(self.run_handler(request.json, allow_modal=False).dump())
+
+            else:
+                raise RuntimeWarning(
+                    f"Interaction type {interaction_type} is not yet supported"
+                )
+
     def set_route_async(self, route, app=None):
         """
         Add a route handler to a Quart app that handles incoming interaction
@@ -615,7 +629,7 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
         if app is None:
             app = self.app
 
-        if aiohttp == None:
+        if aiohttp is None:
             raise ImportError(
                 "The aiohttp module is required for async usage of this " "library"
             )
@@ -635,6 +649,14 @@ class DiscordInteractions(DiscordInteractionsBlueprint):
             elif interaction_type == InteractionType.APPLICATION_COMMAND_AUTOCOMPLETE:
                 result = self.run_autocomplete(request.json)
 
+            elif interaction_type == InteractionType.MODAL_SUBMIT:
+                result = self.run_handler(request.json, allow_modal=False)
+
+            else:
+                raise RuntimeWarning(
+                    f"Interaction type {interaction_type} is not yet supported"
+                )
+
             if inspect.isawaitable(result):
                 result = await result
 
