@@ -9,15 +9,7 @@ from flask_discord_interactions.models.utils import LoadableDataclass
 from flask_discord_interactions.models.component import Component
 from flask_discord_interactions.models.embed import Embed
 
-
-class ResponseType:
-    "Represents the different response type integers."
-    PONG = 1
-    CHANNEL_MESSAGE_WITH_SOURCE = 4
-    DEFERRED_CHANNEL_MESSAGE_WITH_SOURCE = 5
-    DEFERRED_UPDATE_MESSAGE = 6
-    UPDATE_MESSAGE = 7
-    APPLICATION_COMMAND_AUTOCOMPLETE_RESULT = 8
+from flask_discord_interactions.enums import ResponseType
 
 
 @dataclasses.dataclass
